# This file was auto-generated by Fern from our API Definition.

import typing
from .custom_model_id import CustomModelId
from .custom_model_version_id import CustomModelVersionId

CustomModel = typing.Union[CustomModelId, CustomModelVersionId]
