# This file was auto-generated by Fern from our API Definition.

import typing

Bcp47Tag = typing.Union[
    typing.Literal[
        "zh",
        "da",
        "nl",
        "en",
        "en-AU",
        "en-IN",
        "en-NZ",
        "en-GB",
        "fr",
        "fr-CA",
        "de",
        "hi",
        "hi-Latn",
        "id",
        "it",
        "ja",
        "ko",
        "no",
        "pl",
        "pt",
        "pt-BR",
        "pt-PT",
        "ru",
        "es",
        "es-419",
        "sv",
        "ta",
        "tr",
        "uk",
    ],
    typing.Any,
]
