# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from .custom_model_prediction import CustomModelPrediction
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class TlInferencePrediction(UniversalBaseModel):
    file: str = pydantic.Field()
    """
    A file path relative to the top level source URL or file.
    """

    file_type: str
    custom_models: typing.Dict[str, CustomModelPrediction]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
