# This file was auto-generated by Fern from our API Definition.

from .....core.pydantic_utilities import UniversalBaseModel
import typing
from .stream_model_predictions_language_predictions_item import StreamModelPredictionsLanguagePredictionsItem
from .....core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class StreamModelPredictionsLanguage(UniversalBaseModel):
    """
    Response for the language emotion model.
    """

    predictions: typing.Optional[typing.List[StreamModelPredictionsLanguagePredictionsItem]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
