# This file was auto-generated by Fern from our API Definition.

import typing
from .tool_response_message import ToolResponseMessage
from .tool_error_message import ToolErrorMessage

ChatMessageToolResult = typing.Union[ToolResponseMessage, ToolErrorMessage]
