# This file was auto-generated by Fern from our API Definition.

import typing

ReturnLanguageModelModelProvider = typing.Union[
    typing.Literal["OPEN_AI", "CUSTOM_LANGUAGE_MODEL", "ANTHROPIC", "FIREWORKS", "GROQ", "GOOGLE"], typing.Any
]
