# This file was auto-generated by Fern from our API Definition.

from .types import (
    Alternative,
    Bcp47Tag,
    BoundingBox,
    BurstPrediction,
    Classification,
    CompletedEmbeddingGeneration,
    CompletedInference,
    CompletedState,
    CompletedTlInference,
    CompletedTraining,
    CustomModel,
    CustomModelId,
    CustomModelPrediction,
    CustomModelRequest,
    CustomModelVersionId,
    CustomModelsInferenceJob,
    CustomModelsTrainingJob,
    Dataset,
    DatasetId,
    DatasetVersionId,
    DescriptionsScore,
    Direction,
    EmbeddingGenerationBaseRequest,
    EmbeddingGenerationJob,
    EmotionScore,
    Error,
    EvaluationArgs,
    Face,
    FacePrediction,
    FacemeshPrediction,
    FacsScore,
    Failed,
    FailedState,
    File,
    Granularity,
    GroupedPredictionsBurstPrediction,
    GroupedPredictionsFacePrediction,
    GroupedPredictionsFacemeshPrediction,
    GroupedPredictionsLanguagePrediction,
    GroupedPredictionsNerPrediction,
    GroupedPredictionsProsodyPrediction,
    InProgress,
    InProgressState,
    InferenceBaseRequest,
    InferenceJob,
    InferencePrediction,
    InferenceRequest,
    InferenceResults,
    InferenceSourcePredictResult,
    JobEmbeddingGeneration,
    JobId,
    JobInference,
    JobTlInference,
    JobTraining,
    Language,
    LanguagePrediction,
    Models,
    ModelsPredictions,
    Ner,
    NerPrediction,
    Null,
    PositionInterval,
    PredictionsOptionalNullBurstPrediction,
    PredictionsOptionalNullFacePrediction,
    PredictionsOptionalNullFacemeshPrediction,
    PredictionsOptionalTranscriptionMetadataLanguagePrediction,
    PredictionsOptionalTranscriptionMetadataNerPrediction,
    PredictionsOptionalTranscriptionMetadataProsodyPrediction,
    Prosody,
    ProsodyPrediction,
    Queued,
    QueuedState,
    RegistryFileDetail,
    Regression,
    SentimentScore,
    SortBy,
    Source,
    SourceFile,
    SourceTextSource,
    SourceUrl,
    StateEmbeddingGeneration,
    StateEmbeddingGenerationCompletedEmbeddingGeneration,
    StateEmbeddingGenerationFailed,
    StateEmbeddingGenerationInProgress,
    StateEmbeddingGenerationQueued,
    StateInference,
    StateTlInference,
    StateTlInferenceCompletedTlInference,
    StateTlInferenceFailed,
    StateTlInferenceInProgress,
    StateTlInferenceQueued,
    StateTraining,
    StateTrainingCompletedTraining,
    StateTrainingFailed,
    StateTrainingInProgress,
    StateTrainingQueued,
    Status,
    Tag,
    Target,
    Task,
    TaskClassification,
    TaskRegression,
    TextSource,
    TimeInterval,
    TlInferenceBaseRequest,
    TlInferencePrediction,
    TlInferenceResults,
    TlInferenceSourcePredictResult,
    ToxicityScore,
    TrainingBaseRequest,
    TrainingCustomModel,
    Transcription,
    TranscriptionMetadata,
    Type,
    Unconfigurable,
    UnionJob,
    UnionPredictResult,
    Url,
    ValidationArgs,
    When,
    Window,
)

__all__ = [
    "Alternative",
    "Bcp47Tag",
    "BoundingBox",
    "BurstPrediction",
    "Classification",
    "CompletedEmbeddingGeneration",
    "CompletedInference",
    "CompletedState",
    "CompletedTlInference",
    "CompletedTraining",
    "CustomModel",
    "CustomModelId",
    "CustomModelPrediction",
    "CustomModelRequest",
    "CustomModelVersionId",
    "CustomModelsInferenceJob",
    "CustomModelsTrainingJob",
    "Dataset",
    "DatasetId",
    "DatasetVersionId",
    "DescriptionsScore",
    "Direction",
    "EmbeddingGenerationBaseRequest",
    "EmbeddingGenerationJob",
    "EmotionScore",
    "Error",
    "EvaluationArgs",
    "Face",
    "FacePrediction",
    "FacemeshPrediction",
    "FacsScore",
    "Failed",
    "FailedState",
    "File",
    "Granularity",
    "GroupedPredictionsBurstPrediction",
    "GroupedPredictionsFacePrediction",
    "GroupedPredictionsFacemeshPrediction",
    "GroupedPredictionsLanguagePrediction",
    "GroupedPredictionsNerPrediction",
    "GroupedPredictionsProsodyPrediction",
    "InProgress",
    "InProgressState",
    "InferenceBaseRequest",
    "InferenceJob",
    "InferencePrediction",
    "InferenceRequest",
    "InferenceResults",
    "InferenceSourcePredictResult",
    "JobEmbeddingGeneration",
    "JobId",
    "JobInference",
    "JobTlInference",
    "JobTraining",
    "Language",
    "LanguagePrediction",
    "Models",
    "ModelsPredictions",
    "Ner",
    "NerPrediction",
    "Null",
    "PositionInterval",
    "PredictionsOptionalNullBurstPrediction",
    "PredictionsOptionalNullFacePrediction",
    "PredictionsOptionalNullFacemeshPrediction",
    "PredictionsOptionalTranscriptionMetadataLanguagePrediction",
    "PredictionsOptionalTranscriptionMetadataNerPrediction",
    "PredictionsOptionalTranscriptionMetadataProsodyPrediction",
    "Prosody",
    "ProsodyPrediction",
    "Queued",
    "QueuedState",
    "RegistryFileDetail",
    "Regression",
    "SentimentScore",
    "SortBy",
    "Source",
    "SourceFile",
    "SourceTextSource",
    "SourceUrl",
    "StateEmbeddingGeneration",
    "StateEmbeddingGenerationCompletedEmbeddingGeneration",
    "StateEmbeddingGenerationFailed",
    "StateEmbeddingGenerationInProgress",
    "StateEmbeddingGenerationQueued",
    "StateInference",
    "StateTlInference",
    "StateTlInferenceCompletedTlInference",
    "StateTlInferenceFailed",
    "StateTlInferenceInProgress",
    "StateTlInferenceQueued",
    "StateTraining",
    "StateTrainingCompletedTraining",
    "StateTrainingFailed",
    "StateTrainingInProgress",
    "StateTrainingQueued",
    "Status",
    "Tag",
    "Target",
    "Task",
    "TaskClassification",
    "TaskRegression",
    "TextSource",
    "TimeInterval",
    "TlInferenceBaseRequest",
    "TlInferencePrediction",
    "TlInferenceResults",
    "TlInferenceSourcePredictResult",
    "ToxicityScore",
    "TrainingBaseRequest",
    "TrainingCustomModel",
    "Transcription",
    "TranscriptionMetadata",
    "Type",
    "Unconfigurable",
    "UnionJob",
    "UnionPredictResult",
    "Url",
    "ValidationArgs",
    "When",
    "Window",
]
