# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import typing
from .null import Null
from .grouped_predictions_facemesh_prediction import GroupedPredictionsFacemeshPrediction
from ....core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class PredictionsOptionalNullFacemeshPrediction(UniversalBaseModel):
    metadata: typing.Optional[Null] = None
    grouped_predictions: typing.List[GroupedPredictionsFacemeshPrediction]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
