# This file was auto-generated by Fern from our API Definition.

import typing
from .dataset_id import DatasetId
from .dataset_version_id import DatasetVersionId

Dataset = typing.Union[DatasetId, DatasetVersionId]
